class TextSyntax():
    def __init__(self, pattern, types=[], return_type=None):
        pass

    def __call__(self, f):
        def wrapped_f(*args, **kwargs):
            return f(*args, **kwargs)
        return wrapped_f


from natspec_utils.exceptions import MultipleValidationErrors

def multipleMatch(*args):
    import inspect
    methodList = []
    argList = []
    errors = []

    for arg in args:
        if inspect.ismethod(arg):
            methodList.append(arg)
        else:
            argList.append(arg)

    for m in methodList:
        try:
            return m(*argList)
        except (AttributeError, TypeError) as e:
            errors.append(e)

    raise MultipleValidationErrors(errors)


import sys

def stringToUnicode(x):
    """
    This function return a unicode string for all python versions
    """
    if sys.version < '3':
        import codecs
        return codecs.unicode_escape_decode(x)[0]
    return x